package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppFeedingFoodType;

/**
 * 喂养食品类型Service接口
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
public interface IAppFeedingFoodTypeService 
{
    /**
     * 查询喂养食品类型
     * 
     * @param feedingFoodTypeId 喂养食品类型主键
     * @return 喂养食品类型
     */
    public AppFeedingFoodType selectAppFeedingFoodTypeByFeedingFoodTypeId(Long feedingFoodTypeId);

    /**
     * 查询喂养食品类型列表
     * 
     * @param appFeedingFoodType 喂养食品类型
     * @return 喂养食品类型集合
     */
    public List<AppFeedingFoodType> selectAppFeedingFoodTypeList(AppFeedingFoodType appFeedingFoodType);

    /**
     * 新增喂养食品类型
     * 
     * @param appFeedingFoodType 喂养食品类型
     * @return 结果
     */
    public int insertAppFeedingFoodType(AppFeedingFoodType appFeedingFoodType);

    /**
     * 修改喂养食品类型
     * 
     * @param appFeedingFoodType 喂养食品类型
     * @return 结果
     */
    public int updateAppFeedingFoodType(AppFeedingFoodType appFeedingFoodType);

    /**
     * 批量删除喂养食品类型
     * 
     * @param feedingFoodTypeIds 需要删除的喂养食品类型主键集合
     * @return 结果
     */
    public int deleteAppFeedingFoodTypeByFeedingFoodTypeIds(Long[] feedingFoodTypeIds);

    /**
     * 删除喂养食品类型信息
     * 
     * @param feedingFoodTypeId 喂养食品类型主键
     * @return 结果
     */
    public int deleteAppFeedingFoodTypeByFeedingFoodTypeId(Long feedingFoodTypeId);

    /**
     * 查询喂养食品类型列表
     *
     * @return 喂养食品类型集合
     */
    public List<AppFeedingFoodType> getAppFeedingFoodTypeList();
}
